/**
 * Copyright (C) Altimetrik 2018. All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Altimetrik. You shall not disclose such Confidential Information
 * and shall use it only in accordance with the terms and conditions
 * entered into with Altimetrik.
 */

package com.altimetrik.playground.innovation.security;

import java.util.List;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

/**
 * AuthConfig Class.
 * @author Harish Mangala
 */
@Component
public class AuthConfig {

	/**
	 * x-playground-authentication.
	 */
	public static final String X_AUTHENTICATION_TOKEN = "x-playground-authentication";

	/** The default user. */
	@Value("${regulus.security.defaultUser:#{'SYSTEM'}}")
	private String defaultUser;

	/** The default user. */
	@Value("${regulus.security.defaultUserId:#{'SYSTEM'}}")
	private String defaultUserId;

	/** The default realm. */
	@Value("${regulus.security.defaultRealm:#{'REGULUS'}}")
	private String defaultRealm;

	/** The default roles. */
	@Value("${regulus.security.defaultRoles:#{'ROLE_anonymous'}}")
	private String defaultRoles;

	/** The third party authentication users. */
	@Value("${regulus.thirdparty.auth.users:SYSTEM}")
	private List<String> thirdPartyUsers;

	/** The user info mstr id. */
	@Value("${regulus.security.defaultUser:#{0L}}")
	private Long userInfoMstrId;

	/**
	 * Gets thirdPartyUser.
	 * @return the thirdPartyUser
	 */
	public List<String> getThirdPartyUsers() {
		return thirdPartyUsers;
	}

	/**
	 * Gets the default user.
	 *
	 * @return the default user
	 */
	public String getDefaultUser() {
		return defaultUser;
	}

	/**
	 * Gets the default user id.
	 *
	 * @return the default user id
	 */
	public String getDefaultUserId() {
		return defaultUserId;
	}

	public Long getUserInfoMstrId() {
		return userInfoMstrId;
	}

	public void setUserInfoMstrId(Long userInfoMstrId) {
		this.userInfoMstrId = userInfoMstrId;
	}

	/**
	 * Gets the default realm.
	 *
	 * @return the default realm
	 */
	public String getDefaultRealm() {
		return defaultRealm;
	}

	/**
	 * Gets the default roles.
	 *
	 * @return the default roles
	 */
	public String getDefaultRoles() {
		return defaultRoles;
	}

}
